package com.example.demo;

import java.io.IOException;
import java.io.InputStreamReader;
import java.io.Reader;
import java.sql.Connection;

import javax.sql.DataSource;

import org.apache.ibatis.io.Resources;
import org.apache.ibatis.jdbc.ScriptRunner;
import org.mybatis.spring.annotation.MapperScan;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.SpringApplication;
import org.springframework.boot.autoconfigure.SpringBootApplication;
import org.springframework.boot.context.event.ApplicationReadyEvent;
import org.springframework.context.event.EventListener;

import jakarta.annotation.PostConstruct;

@SpringBootApplication
@MapperScan("com.example.demo.repository")
public class MainApplication {

	@Autowired
	private DataSource dataSource;

	public static void main(String[] args) {
		SpringApplication.run(MainApplication.class, args);
	}

	@PostConstruct
	public void runSqlScript() throws Exception {
		// It is not working in in-memory SQLite
		this.initDatabaseAndInsertSampleData();
	}

	/**
	 * 
	 */
	@EventListener(ApplicationReadyEvent.class)
	public void doSomethingAfterStartup() {
		System.out.println("hello world, I have just started up");

	}

	private void initDatabaseAndInsertSampleData() throws Exception {

		// Database initialization
		Connection conn = dataSource.getConnection();
		ScriptRunner runner = new ScriptRunner(conn);
		runner.setStopOnError(true);
		runner.setEscapeProcessing(false); // Important!
		// runner.setSendFullScript(false);
		runner.setAutoCommit(true);

		// Init schemas
		Reader schema = Resources.getResourceAsReader("sqlite/schema.sql");
		runner.runScript(schema);

		// Insert sample data
		Reader sampledata = Resources.getResourceAsReader("sqlite/create-sample-data.sql");
		runner.runScript(sampledata);

	}
}
