package com.example.demo.controller;

import org.springframework.web.bind.annotation.RestController;

import com.example.demo.model.User;
import com.example.demo.services.UserService;

import org.springframework.web.bind.annotation.RequestMapping;
import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.CrossOrigin;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;

/**
 * The Controller Class for User API
 * 
 * NOTE: By adding @CrossOrigin, Swagger preview can work perfectly.
 * 
 * TODO:
 * 1) How to set response content type to json by default
 * 2) Handling errors
 */
@RestController
@CrossOrigin
@RequestMapping(value = "/api/v1/users")
public class UserController {
    @Autowired
    private UserService userService;

    /**
     * Get all users
     * 
     * Method: GET
     * Endpoint: /users or /users/
     * 
     * @return List of User object
     */
    @GetMapping(value = { "", "/" }, produces = "application/json")
    public List<User> getUsers() {
        List<User> users = userService.getUsers();
        return users;

    }

    /**
     * Get the user by id
     * 
     * Method: GET
     * Endpoint: /users/{id}
     * 
     * TODO:
     * 1) Return 404 if not found
     * 2) Return correct status code like 200
     * 
     * @param userId the userId (= path variable {id})
     * @return The User object. Empty content will be returned if not found
     */
    @GetMapping(value = "{id}", produces = "application/json")
    public User getUsersById(@PathVariable("id") String userId) {
        User user = userService.getUserById(Integer.parseInt(userId));
        return user;

    }

    /**
     * Add a user
     * 
     * Method: POST
     * Endpoint: /users
     * 
     * @param user The User object with required fields. See swagger file
     * @return The added user object
     */
    @PostMapping(value = "", produces = "application/json")
    public User addUser(@RequestBody User user) {
        int id = userService.addUser(user);
        // if success, get the user and return the created user
        User addedUser = userService.getUserById(id);
        return addedUser;
    }
}
