package com.example.demo.services;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.example.demo.model.User;
import com.example.demo.repository.UserMapper;

/**
 * Service class for User
 */
@Service
public class UserService {
    @Autowired
    UserMapper userMapper;

    /**
     * Add the user
     * 
     * @param user The user object for adding
     * @return Added user's id
     */
    public int addUser(User user) {
        // NOTE: the mapper will return the number of row inserted
        // not the generated ID.
        // int rowInserted = userMapper.addUser(user);

        userMapper.addUser(user);
        return user.getId();
    }

    /**
     * Get user by id
     * 
     * @param id user id
     * @return The user, null will be returned if not exist.
     */
    public User getUserById(int id) {
        return userMapper.getUserById(id);
    }

    /**
     * Get all user (without pagination)
     * NOTE: It will cause problem if the number of record is large.
     * 
     * @return A list of User object. The result.
     */
    public List<User> getUsers() {
        return userMapper.getUsers();
    }
}
